// qjackctlAbout.h
//
/****************************************************************************
   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*****************************************************************************/

#ifndef __qjackctlAbout_h
#define __qjackctlAbout_h

#include "config.h"

#define QJACKCTL_TITLE      PACKAGE_NAME

#define QJACKCTL_SUBTITLE0  "JACK"
#define QJACKCTL_SUBTITLE1  QJACKCTL_SUBTITLE0 " Audio Connection Kit"
#define QJACKCTL_SUBTITLE2  "Qt GUI Interface"

#define QJACKCTL_SUBTITLE   QJACKCTL_SUBTITLE1 " - " QJACKCTL_SUBTITLE2
#define QJACKCTL_WEBSITE    "https://qjackctl.sourceforge.io"
#define QJACKCTL_COPYRIGHT  "Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved."

#define QJACKCTL_DOMAIN     "rncbc.org"

#endif  // __qjackctlAbout_h

// end of qjackctlAbout.h
